%define octave_api  60
%define major       12
%define majorinterp 13
%define guimajor    13
%define octmexmajor 1

%bcond_without  audio
%bcond_without  gui
%bcond_without  java

%global macrosdir %(d=%{_rpmconfigdir}/macros.d; [ -d $d ] || d=%{_sysconfdir}/rpm; echo $d)

Name:           octave
Epoch:          0
Version:        10.2.0
Release:        %mkrel 1
Summary:        High-level language for numerical computations
License:        GPLv3+
Group:          Sciences/Mathematics
URL:            https://www.octave.org/
Source0:        https://ftp.gnu.org/gnu/octave/%{name}-%{version}.tar.lz
Source1:        macros.octave
Source4:        octave-2.1.36-emac.lisp
# Patch from https://savannah.gnu.org/bugs/?54607, merged from opensuse
# (see https://savannah.gnu.org/bugs/download.php?file_id=48434
Patch0:		0001-Disable-signal-handler-thread-avoid-duplicate-signal.patch
# fix output for pslatexstandalone or pdflatexstandalone
Patch1:		0001-Fix-amsmath-required-package-in-pslatexstandalone-or.patch
# from git upstream

Obsoletes:      octave3 < %{epoch}:%{version}-%{release}
Provides:       octave3 = %{epoch}:%{version}-%{release}
Provides:       octave(api) = api-v%{octave_api}
Recommends:     gnuplot

# Required for exporting in EPS from GUI plot
Requires:	epstool
# (Anssi) for makeinfo which is needed for "help foo" command:
Requires:       texinfo
Requires:       graphicsmagick
Requires(post): desktop-file-utils
Requires(postun): desktop-file-utils
Requires(post): rpm-helper

#(eatdirt) qtoctave is dead, does not work with this version and
#octave now provides octave --gui
Obsoletes:      qtoctave <= 0.10.1
Provides:       qtoctave = %{version}-%{release}

BuildRequires:  lzip
BuildRequires:  bison
BuildRequires:  blas-devel
BuildRequires:  dejagnu
BuildRequires:  desktop-file-utils
BuildRequires:  emacs
BuildRequires:  emacs-bin
BuildRequires:  fftw-devel >= 0:3.0.1
BuildRequires:  flex
BuildRequires:  gcc-gfortran
BuildRequires:  glpk-devel
BuildRequires:  gnuplot-nox
# (Abel) not strictly needed, but play safe
BuildRequires:  gperf
BuildRequires:  hdf5-devel
BuildRequires:  lapack-devel
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  pkgconfig(readline)
BuildRequires:  texinfo
BuildRequires:  texinfo-tex
BuildRequires:  texlive
BuildRequires:  pkgconfig(libpcre2-8)
BuildRequires:  pkgconfig(libcurl)
# (Lev) needed to support sparse matrix functionality
BuildRequires:  suitesparse-devel >= 5.0
# (Lev) other useful libraries
BuildRequires:  qhull-devel
BuildRequires:  qrupdate-devel
# (Lev) for new experimental plotting
BuildRequires:  fltk-devel
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glu)
# (Mitya) for eigs and svds to work
BuildRequires:  pkgconfig(arpack)
# to make imread more functional
BuildRequires:  pkgconfig(GraphicsMagick)
# (papoteur) build against Qt6
%if %{with gui}
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6Network)
BuildRequires:  cmake(Qt6OpenGL)
BuildRequires:  cmake(Qt6PrintSupport)
BuildRequires:  cmake(Qt6Help)
BuildRequires:  cmake(Qt6Xml)
BuildRequires:  cmake(Qt6OpenGLWidgets)
BuildRequires:  cmake(Qt6Core5Compat)
BuildRequires:  qscintilla-qt6-devel
%endif
# (Mitya) Java interface
%if %{with java}
BuildRequires:  java-devel
%endif
# (Mitya) rendering stuff
BuildRequires:  gl2ps-devel
BuildRequires:  pkgconfig(dri)
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(glesv2)
# (Mitya) Audio processing
%if %{with audio}
BuildRequires:  pkgconfig(portaudio-2.0)
BuildRequires:  pkgconfig(sndfile)
%endif
# (eatdirt) fix some warnings for icon generation
BuildRequires:  icoutils
BuildRequires:  librsvg
BuildRequires:  sundials-devel
# For JSON support.
# There were issues with rapidjson and prettywriter requirements; ensure to have the patched package:
# (see https://github.com/Tencent/rapidjson/issues/909 and https://github.com/Tencent/rapidjson/issues/1718)
BuildRequires:  pkgconfig(RapidJSON) >= 1.1.0-6

%description
GNU Octave is a high-level language, primarily intended for numerical
computations. It provides a convenient command line interface for
solving linear and nonlinear problems numerically, and for performing
other numerical experiments using a language that is mostly compatible
with Matlab. It may also be used as a batch-oriented language.

Octave has extensive tools for solving common numerical linear algebra
problems, finding the roots of nonlinear equations, integrating
ordinary functions, manipulating polynomials, and integrating ordinary
differential and differential-algebraic equations. It is easily
extensible and customizable via user-defined functions written in
Octave's own language, or using dynamically loaded modules written in
C++, C, Fortran, or other languages.

%package devel
Summary:        Development headers and files for Octave
Group:          Development/C
Obsoletes:      octave3-devel < %{epoch}:%{version}-%{release}
Provides:       octave3-devel = %{epoch}:%{version}-%{release}
Requires:       %{name} = %{epoch}:%{version}-%{release}
Requires:       blas-devel
Requires:       fftw-devel
Requires:       gcc-c++
Requires:       gcc-gfortran
Requires:       hdf5-devel
Requires:       lapack-devel
Requires:       readline-devel
# beware: for correct building function uncompress2() is required in zlib which is
# available since zlib 1.2.12.
# (mga8's zlib have, however, removed uncompress2() function from its zlib-1.2.12)
Requires:       zlib-devel >= 1.2.12
Requires:       gnuplot-nox
Requires:       pstoedit
Requires:       transfig
Provides:       mkoctfile = %{epoch}:%{version}-%{release}

%description devel
The octave-devel package contains files needed for developing
applications which use GNU Octave.
This package is necessary if you intend to install external packages
(for example, through Octave forge) in Octave.

%package doc
Summary:        Documentation for Octave, a numerical computational language
Group:          Sciences/Mathematics
BuildArch:      noarch

%description doc
GNU Octave is a high-level language, primarily intended for numerical
computations. It provides a convenient command line interface for
solving linear and nonlinear problems numerically, and for performing
other numerical experiments using a language that is mostly compatible
with Matlab. It may also be used as a batch-oriented language.

This package contains documentation of Octave in various formats.


%prep
%setup -q
%autopatch -p1

#this command just returns the API number hardcoded in configure.ac
#and ensures that it matches the one defined above
OCTAVE_API=`%{__sed} -nr 's/^OCTAVE_API_VERSION="api-v([[:digit:]]+)"/\1/p' configure.ac`
test "x${OCTAVE_API}" = x%{octave_api} || exit 1
%{__cp} -a %{SOURCE4} octave.el


%build
# flag to control building octave with 64bit array indexes
%define enable64 no
export CPPFLAGS="%{optflags} -DH5_USE_16_API"
export GNUPLOT=%{_bindir}/gnuplot-nox
export JAVA_HOME="%{_prefix}/lib/jvm/java"
export EGREP="grep -E"
%{configure} \
                 --enable-shared \
                 --disable-static \
                 --enable-64=%{enable64} \
                 --with-amd="-lamd -lsuitesparseconfig" \
                 --with-camd="-lcamd -lsuitesparseconfig" \
                 --with-colamd="-lcolamd -lsuitesparseconfig" \
                 --with-ccolamd="-lccolamd -lsuitesparseconfig" \
                 --enable-link-all-dependencies \
                 --disable-rpath \
                 --with-qrupdate \
                 --with-cxsparse \
                 --disable-docs


##(eatdirt) --with-gnu-ld enable-link-dep is required to import and
##compile octave third party packages. See bug 25616

# (Mitya) Because of gnuplot-nox used for build, Octave will set it as default gnuplot binary.
# Revert it to original gnuplot.
#{__sed} -i 's/gnuplot-nox/gnuplot/' scripts/plot/util/gnuplot_binary.m

%make_build OCTAVE_RELEASE="%{distribution} %{version}-%{release}" LDFLAGS="-lgfortran -llapack -lGL -lGLU -lpthread"

# emacs mode
%{_bindir}/emacs -batch -q -no-site-file -f batch-byte-compile %{name}.el


%install
%make_install

# Make library links
%{__mkdir_p} %{buildroot}/etc/ld.so.conf.d
/bin/echo "%{_libdir}/octave/%{version}" > %{buildroot}/etc/ld.so.conf.d/octave-%{_arch}.conf

# Remove RPM_BUILD_ROOT from ls-R files
%{__perl} -pi -e "s,%{buildroot},," %{buildroot}%{_libexecdir}/octave/ls-R
%{__perl} -pi -e "s,%{buildroot},," %{buildroot}%{_datadir}/octave/ls-R

%{_bindir}/find %{buildroot} -name "*.oct" -print0 | %{_bindir}/xargs -t -0 -r strip --strip-unneeded

%{__mkdir_p} %{buildroot}%{_sysconfdir}/emacs/site-start.d
%{__cp} -a %{name}.elc %{buildroot}%{_sysconfdir}/emacs/site-start.d/%{name}.elc
%{__cp} -a %{name}.el %{buildroot}%{_sysconfdir}/emacs/site-start.d/%{name}.el

# prepare documentation
%{__rm} -rf package-doc
%{__mkdir_p} package-doc

%{__mkdir_p} package-doc/interpreter/octave.html/
/bin/ln doc/interpreter/octave.html/*.html package-doc/interpreter/octave.html/

%{__mkdir_p} package-doc/liboctave/liboctave.html/
/bin/ln doc/liboctave/liboctave.html/*.html package-doc/liboctave/liboctave.html/

%{__mkdir_p} package-doc/examples
%{__cp} -a examples/[[:lower:]]* package-doc/examples/

#%{__cp} -a doc/liboctave/liboctave.info %{buildroot}%{_infodir}/

# Create desktop file
%{__mv} %{buildroot}%{_datadir}/applications/org.octave.Octave.desktop \
        %{buildroot}%{_datadir}/applications/octave.desktop
%{_bindir}/desktop-file-install --add-category Education --remove-category Development \
        --dir %{buildroot}%{_datadir}/applications %{buildroot}%{_datadir}/applications/octave.desktop

# Create directories for add-on packages
HOST_TYPE=`%{buildroot}%{_bindir}/octave-config -p CANONICAL_HOST_TYPE`
%{__mkdir_p} %{buildroot}%{_libexecdir}/octave/site/oct/%{octave_api}/$HOST_TYPE
%{__mkdir_p} %{buildroot}%{_libexecdir}/octave/site/oct/$HOST_TYPE
%{__mkdir_p} %{buildroot}%{_datadir}/octave/packages
/bin/touch %{buildroot}%{_datadir}/octave/octave_packages

%multiarch_includes %{buildroot}%{_includedir}/octave-%{version}/octave/*.h


#(eatdirt) remove .la files
find %{buildroot}%{_libdir} -name "*.la" -delete
echo %{buildroot}%{_libdir}


#(eatdirt) trigger libification with symlinks (thanks tv)
pushd %{buildroot}%{_libdir}
ln -s ./octave/%{version}/liboctave.so liboctave.so
ln -s ./octave/%{version}/liboctinterp.so liboctinterp.so
ln -s ./octave/%{version}/liboctgui.so liboctgui.so
popd

# rpm macros
mkdir -p %{buildroot}%{macrosdir}
cp -p %SOURCE1 %{buildroot}%{macrosdir}

%post
%create_ghostfile %{_datadir}/octave/octave_packages root root 0664


%files
%defattr(0644,root,root,0755)
%doc NEWS* README
%doc examples
%defattr(-,root,root,0755)
%{_bindir}/octave*
%config(noreplace) /etc/ld.so.conf.d/*
#(eatdirt) fix packaging of libraries (.so files go to devel)
%{_libdir}/octave/site
%{_libdir}/octave/%{version}/oct
%{_libdir}/octave/%{version}/liboctave.so.%{major}{,.*}
%{_libdir}/octave/%{version}/liboctinterp.so.%{majorinterp}{,.*}
%{_libdir}/octave/%{version}/liboctgui.so.%{guimajor}{,.*}
%{_libdir}/octave/%{version}/liboctmex.so.%{octmexmajor}{,.*}
%{_datadir}/octave
%{_datadir}/metainfo/org.octave.Octave.metainfo.xml
%{_datadir}/icons/*/*/apps/octave.png
%{_datadir}/icons/*/*/apps/octave.svg
%exclude %{_datadir}/octave/octave_packages
%ghost %{_datadir}/octave/octave_packages
#(eatdirt) why should they be the same?
#if "#{_libdir}" != "#{_libexecdir}"
#{_libexecdir}/octave
#endif
%{_libexecdir}/octave
#{_mandir}/man*/octave*
#{_infodir}/octave.info*
%{_datadir}/applications/*
%config(noreplace) %_sysconfdir/emacs/site-start.d/octave.el*

%files devel
%{macrosdir}/macros.octave
%{_bindir}/mkoctfile*
%{_libdir}/pkgconfig/*.pc
#(eatdirt) adding library devel files
%{_libdir}/octave/%{version}/*.so
%{_libdir}/*.so
%{_includedir}/octave-%{version}
%dir %{multiarch_includedir}/octave-*
%multiarch %{multiarch_includedir}/octave-*/octave/*.h
%multiarch %{multiarch_includedir}/octave-*/octave/*.cc
#{_mandir}/man*/mkoctfile*

%files doc
%defattr(0644,root,root,0755)
%doc doc/refcard/*.pdf
%doc doc/interpreter/*.pdf
%doc doc/liboctave/*.pdf
%doc package-doc/*
#{_infodir}/liboctave.*


%changelog
* Sun Jul 06 2025 ghibo <ghibo> 0:10.2.0-1.mga10
+ Revision: 2247930
- Fix files list
- Update to version 10.2.0.
- Use .tar.lz as it's shorter.
- Fix major.
+ umeabot <umeabot>
- Mageia 10 Mass Rebuild

* Thu Sep 05 2024 eatdirt <eatdirt> 0:9.2.0-1.mga10
+ Revision: 2093281
- Update to version 9.2.0

* Thu May 23 2024 papoteur <papoteur> 0:9.1.0-2.mga10
+ Revision: 2066836
- rebuild for new libsundials

* Mon Mar 18 2024 papoteur <papoteur> 0:9.1.0-1.mga10
+ Revision: 2050446
- new version 9.1.0- switch to Qt6

* Sat Jun 03 2023 ghibo <ghibo> 0:8.2.0-2.mga9
+ Revision: 1960604
- Use grep -E instead of egrep

* Wed May 31 2023 ghibo <ghibo> 0:8.2.0-1.mga9
+ Revision: 1960417
- Update to release 8.2.0.
- Remove patch merged upstream.
- Rebuild against newer libsundials.

* Sun Apr 16 2023 daviddavid <daviddavid> 0:8.1.0-3.mga9
+ Revision: 1953279
- enable pcre2 support

* Wed Mar 22 2023 ghibo <ghibo> 0:8.1.0-2.mga9
+ Revision: 1950033
- Merge patch from upstream to speedup loading and saving preferences dialog
- Rework Patch1.

* Thu Mar 16 2023 ghibo <ghibo> 0:8.1.0-1.mga9
+ Revision: 1949525
- Update to release 8.1.0.
- Rework signal-handler patch.
- Add patch to fix broken output in pslatexstandalone or pdflatexstandalone output devices.

* Mon Dec 05 2022 eatdirt <eatdirt> 0:7.3.0-2.mga9
+ Revision: 1918308
- Rebuild for new hdf5

* Fri Dec 02 2022 joequant <joequant> 0:7.3.0-1.mga9
+ Revision: 1913955
- update to 7.3.0

* Sat Sep 03 2022 joequant <joequant> 0:7.2.0-2.mga9
+ Revision: 1883616
- rebuild with new libraries

* Fri Aug 19 2022 ghibo <ghibo> 0:7.2.0-1.mga9
+ Revision: 1878761
- Remove patches merged upstream
- Update to release 7.2.0

* Sat May 14 2022 ghibo <ghibo> 0:7.1.0-6.mga9
+ Revision: 1858173
- Rebuilt against latest graphicsmagick having qdepth of 16

* Sat May 14 2022 ghibo <ghibo> 0:7.1.0-5.mga9
+ Revision: 1858151
- Add upstream patches to fix leak of build directories into installed dirs.
- Use %%make_build and %%make_install instead of version in between brackets (cosmetic).

* Sat May 14 2022 ghibo <ghibo> 0:7.1.0-4.mga9
+ Revision: 1858134
- add rapidjson to BuildRequires.
- pack exaggerated multiple blank line seps (cosmetic) between sections in spec file.
- merge patch0 from git (same used by opensuse) to fix signal handler timeouts with a local samba server.
- specify JAVA_HOME to avoid configure warnigs.

* Tue May 03 2022 ghibo <ghibo> 0:7.1.0-3.mga9
+ Revision: 1856000
- Add epstool to Requires, needed for exporting in EPS from plot window.
- Explicit versioning and warning for zlib-devel (useful for backports).

* Sat Apr 30 2022 joequant <joequant> 0:7.1.0-2.mga9
+ Revision: 1855196
- rebuild with new suitesparse

* Sat Apr 16 2022 ghibo <ghibo> 0:7.1.0-1.mga9
+ Revision: 1850711
- Update to release 7.1.0

* Wed Apr 06 2022 umeabot <umeabot> 0:6.4.0-2.mga9
+ Revision: 1845984
- Mageia 9 Mass Rebuild

* Mon Jan 31 2022 mrambo3501 <mrambo3501> 0:6.4.0-1.mga9
+ Revision: 1770791
- version 6.4.0

* Sun Oct 03 2021 joequant <joequant> 0:6.3.0-1.mga9
+ Revision: 1748884
- update to 6.3.0

* Sat Aug 28 2021 tv <tv> 0:6.1.0-2.mga9
+ Revision: 1743134
- Rebuild for new sundials

* Tue Dec 22 2020 eatdirt <eatdirt> 0:6.1.0-1.mga8
+ Revision: 1662932
- Upgrade to version 6.1.0

* Fri Dec 18 2020 luigiwalser <luigiwalser> 0:5.2.0-10.mga8
+ Revision: 1660969
- rebuild for missing signature

* Thu Dec 17 2020 umeabot <umeabot> 0:5.2.0-9.mga8
+ Revision: 1659146
- Rebuild for new Qt5

* Thu Nov 19 2020 daviddavid <daviddavid> 0:5.2.0-8.mga8
+ Revision: 1647500
- rebuild with fixed qhull

* Wed Nov 18 2020 tv <tv> 0:5.2.0-7.mga8
+ Revision: 1647097
- rebuild for new qhull

* Sun Jun 28 2020 joequant <joequant> 0:5.2.0-6.mga8
+ Revision: 1600042
- rebuild for arm

* Mon Jun 22 2020 joequant <joequant> 0:5.2.0-5.mga8
+ Revision: 1598433
- fix ln -s typo
- update with qhull 2020
+ pterjan <pterjan>
- Remove usage of obsolete macros (https://github.com/rpm-software-management/rpm/issues/1211)

* Sun Mar 08 2020 joequant <joequant> 0:5.2.0-3.mga8
+ Revision: 1554885
- change suggests to recommends

* Sat Mar 07 2020 joequant <joequant> 0:5.2.0-2.mga8
+ Revision: 1554581
- turn gnuplot into suggests as octave now has non-gnuplot plotting

* Sat Feb 22 2020 shlomif <shlomif> 0:5.2.0-1.mga8
+ Revision: 1549371
- New version 5.2.0

* Tue Feb 18 2020 umeabot <umeabot> 0:5.1.0-10.mga8
+ Revision: 1542189
- Mageia 8 Mass Rebuild

* Sat Jan 04 2020 luigiwalser <luigiwalser> 0:5.1.0-9.mga8
+ Revision: 1475993
- rebuild for readline

* Tue Nov 05 2019 eatdirt <eatdirt> 0:5.1.0-8.mga8
+ Revision: 1458043
- Force link dependencies to fix mga#25617

* Sun Mar 31 2019 umeabot <umeabot> 0:5.1.0-7.mga7
+ Revision: 1383589
- Qt5 Rebuild

* Fri Mar 08 2019 eatdirt <eatdirt> 0:5.1.0-6.mga7
+ Revision: 1372896
- Add symlinks to .so file to trigger missing libification

* Wed Mar 06 2019 eatdirt <eatdirt> 0:5.1.0-4.mga7
+ Revision: 1371920
- Tentative fix of missing devel files, obsoletes qtoctave
- Fix packaging of library devel files

* Tue Mar 05 2019 eatdirt <eatdirt> 0:5.1.0-2.mga7
+ Revision: 1371706
- Fixing wrong ld.conf file and disabling rpath

* Tue Mar 05 2019 eatdirt <eatdirt> 0:5.1.0-1.mga7
+ Revision: 1371639
- Upgrade to version 5.1.0

* Fri Nov 09 2018 joequant <joequant> 0:4.4.1-3.mga7
+ Revision: 1329220
- upgrade hdf5

* Thu Nov 08 2018 daviddavid <daviddavid> 0:4.4.1-2.mga7
+ Revision: 1328945
- rebuild for new hdf5 1.10.4

* Sun Oct 14 2018 shlomif <shlomif> 0:4.4.1-1.mga7
+ Revision: 1320352
- New version 4.4.1

* Mon Sep 03 2018 tv <tv> 0:4.4.0-3.mga7
+ Revision: 1256621
- rely on filetriggers for info system (mga#23482)

* Tue Jul 31 2018 eatdirt <eatdirt> 0:4.4.0-2.mga7
+ Revision: 1246442
- Rebuild for new gfortran

* Sun May 13 2018 eatdirt <eatdirt> 0:4.4.0-1.mga7
+ Revision: 1229198
- Upgrade to version 4.4.0

* Thu Apr 19 2018 daviddavid <daviddavid> 0:4.2.2-2.mga7
+ Revision: 1220178
- rebuild for new qscintilla 2.10.4

* Wed Mar 14 2018 kekepower <kekepower> 0:4.2.2-1.mga7
+ Revision: 1209544
- Update to version 4.2.2

* Thu Nov 02 2017 mjack <mjack> 0:4.2.1-5.mga7
+ Revision: 1175622
- Added Provides: mkoctfile for octave-devel

* Mon Oct 16 2017 mjack <mjack> 0:4.2.1-4.mga7
+ Revision: 1172270
- Added info in octave-devel description
- Added Requires: graphicsmagick

* Mon Sep 11 2017 tv <tv> 0:4.2.1-3.mga7
+ Revision: 1152748
- rebuild for new libgfortran

* Wed May 03 2017 eatdirt <eatdirt> 0:4.2.1-2.mga6
+ Revision: 1098827
- Rebuild for new gl2ps, fix compilation warnings

* Fri Mar 03 2017 eatdirt <eatdirt> 0:4.2.1-1.mga6
+ Revision: 1088563
- Upgrade to version 4.2.1

* Fri Dec 02 2016 eatdirt <eatdirt> 0:4.2.0-1.mga6
+ Revision: 1071703
- Upgrade to version 4.2.0

* Fri Sep 30 2016 eatdirt <eatdirt> 0:4.0.3-1.mga6
+ Revision: 1057870
- Upgrade to bugfix release 4.0.3

* Sat Apr 16 2016 shlomif <shlomif> 0:4.0.1-2.mga6
+ Revision: 1003004
- Rebuild for the new glpk

* Fri Apr 01 2016 eatdirt <eatdirt> 0:4.0.1-1.mga6
+ Revision: 997314
- Update to bug fixing release 4.0.1

* Mon Mar 14 2016 daviddavid <daviddavid> 0:4.0.0-6.mga6
+ Revision: 990435
- rebuild for new qhull 2015.2

* Tue Feb 16 2016 umeabot <umeabot> 0:4.0.0-5.mga6
+ Revision: 961812
- Mageia 6 Mass Rebuild

* Wed Dec 30 2015 mitya <mitya> 0:4.0.0-4.mga6
+ Revision: 916873
- introduce conditionals for GUI, Java and audio
- build with everything by default

* Tue Dec 29 2015 mitya <mitya> 0:4.0.0-3.mga6
+ Revision: 916858
- enable: GUI, Java, sparse matrices
- audio processing disabled by default, use --with audio
- use gnuplot-nox for build
- minor cleanups

* Tue Dec 29 2015 tv <tv> 0:4.0.0-2.mga6
+ Revision: 916739
- rebuild for new libGraphicsMagick

* Mon Nov 09 2015 shlomif <shlomif> 0:4.0.0-1.mga6
+ Revision: 900084
- New version 4.0.0

* Sun Aug 16 2015 ycantin <ycantin> 0:3.8.2-5.mga6
+ Revision: 865134
- rebuild for libfltk

* Tue Jul 21 2015 daviddavid <daviddavid> 0:3.8.2-4.mga6
+ Revision: 855869
- rebuild with new hdf5

* Wed Oct 15 2014 umeabot <umeabot> 0:3.8.2-3.mga5
+ Revision: 741674
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild

* Thu Sep 04 2014 grenoya <grenoya> 0:3.8.2-1.mga5
+ Revision: 671908
- new version 3.8.2
- disable all SuiteSparse module at build due to incompatibility between Octave and new SuiteSparse 4.3.x (Octave bug #43063)

* Sun Mar 16 2014 grenoya <grenoya> 0:3.8.1-3.mga5
+ Revision: 604275
- new version 3.8.1

* Tue Oct 22 2013 umeabot <umeabot> 0:3.6.4-3.mga4
+ Revision: 545563
- Mageia 4 Mass Rebuild

* Wed Oct 16 2013 grenoya <grenoya> 0:3.6.4-2.mga4
+ Revision: 501406
- rebuild for new suitesparse

* Wed Oct 09 2013 grenoya <grenoya> 0:3.6.4-1.mga4
+ Revision: 494208
- new version 3.6.4

* Tue Jul 16 2013 fwang <fwang> 0:3.6.3-4.mga4
+ Revision: 455024
- rebuild for new hdf5

* Thu Jan 17 2013 pterjan <pterjan> 0:3.6.3-3.mga4
+ Revision: 389214
+ rebuild (emptylog)

* Sun Jan 13 2013 umeabot <umeabot> 0:3.6.3-3.mga3
+ Revision: 361782
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Dec 01 2012 fwang <fwang> 0:3.6.3-2.mga3
+ Revision: 323831
- rebuild for new pcre

* Sat Sep 22 2012 grenoya <grenoya> 0:3.6.3-1.mga3
+ Revision: 296721
- new version 3.6.3

* Thu Apr 05 2012 mitya <mitya> 0:3.6.1-2.mga2
+ Revision: 228781
- Build with ARPACK to support eigs and svds functions

* Thu Mar 01 2012 grenoya <grenoya> 0:3.6.1-1.mga2
+ Revision: 216573
- update to 3.6.1
+ fwang <fwang>
- mark doc package as noarch

* Wed Jan 18 2012 grenoya <grenoya> 0:3.4.3-4.mga2
+ Revision: 197868
- fix flags for linkage
- add gnuplot-nox, pstoedit and transfig for better functioning
+ anssi <anssi>
- require texinfo, needed for the "help" command to work properly

* Sat Dec 10 2011 grenoya <grenoya> 0:3.4.3-2.mga2
+ Revision: 180467
- add missing pdf files

* Sat Nov 12 2011 grenoya <grenoya> 0:3.4.3-1.mga2
+ Revision: 166963
- new version 3.4.3

* Sat Sep 03 2011 grenoya <grenoya> 0:3.4.2-1.mga2
+ Revision: 138319
- build without parallel make
- fix new info and html doc path
- fix octave.desktop build
- fix rpm file content
+ misc <misc>
- remove old file from sha1.lst
+ fwang <fwang>
- fix linkage
- fix build with latest curl
- new version 3.4.2
- rebuild for new fltk

* Mon Jun 20 2011 grenoya <grenoya> 0:3.2.4-6.mga2
+ Revision: 110415
- rebuild after upgrade of umfpack library

* Mon Apr 18 2011 grenoya <grenoya> 0:3.2.4-5.mga1
+ Revision: 87881
-rebuild for new version of qhull

* Fri Apr 15 2011 grenoya <grenoya> 0:3.2.4-4.mga1
+ Revision: 85774
- clean old Mdv syntax
- put texlive requirement instead of tetex-*
- imported package octave


* Sun Sep 19 2010 Tomas Kindl <supp@mandriva.org> 0:3.2.4-4mdv2011.0
+ Revision: 579806
- bump correction
- fix patch :-/ so it will apply
- fix #60878

* Tue Aug 10 2010 Ahmad Samir <ahmadsamir@mandriva.org> 0:3.2.4-3mdv2011.0
+ Revision: 568870
- add BR GraphicsMagick-devel to make imread more functional

* Fri Aug 06 2010 Funda Wang <fwang@mandriva.org> 0:3.2.4-2mdv2011.0
+ Revision: 566597
- rebuild for new amd

* Thu Jan 28 2010 Frederik Himpe <fhimpe@mandriva.org> 0:3.2.4-1mdv2010.1
+ Revision: 497676
- update to new version 3.2.4

* Fri Jan 08 2010 Frederik Himpe <fhimpe@mandriva.org> 0:3.2.3-5mdv2010.1
+ Revision: 487736
- rebuild

* Mon Jan 04 2010 Paulo Andrade <pcpa@mandriva.com.br> 0:3.2.3-4mdv2010.1
+ Revision: 486214
+ rebuild (emptylog)

* Thu Oct 22 2009 Paulo Andrade <pcpa@mandriva.com.br> 0:3.2.3-3mdv2010.0
+ Revision: 458655
- Correct i586 build by using 3.2.2 semantics

* Thu Oct 08 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 0:3.2.3-2mdv2010.0
+ Revision: 455897
- rebuild for new curl SSL backend

* Sat Sep 26 2009 Frederik Himpe <fhimpe@mandriva.org> 0:3.2.3-1mdv2010.0
+ Revision: 449639
- update to new version 3.2.3

* Thu Jul 23 2009 Frederik Himpe <fhimpe@mandriva.org> 0:3.2.2-1mdv2010.0
+ Revision: 398744
- Update to new version 3.2.2

* Wed Jun 17 2009 Lev Givon <lev@mandriva.org> 0:3.2.0-1mdv2010.0
+ Revision: 386496
- Update to 3.2.0.

* Wed Apr 22 2009 Lev Givon <lev@mandriva.org> 0:3.0.5-1mdv2010.0
+ Revision: 368690
- Update to 3.0.5.
  Suitesparse patch no longer needed.

* Wed Feb 25 2009 Thierry Vignaud <tv@mandriva.org> 0:3.0.3-2mdv2009.1
+ Revision: 344822
- rebuild for new libreadline

* Sun Feb 15 2009 Frederik Himpe <fhimpe@mandriva.org> 0:3.0.3-1mdv2009.1
+ Revision: 340632
- Update to new version 3.0.3
- Add patch to fix build with suitesparse 3.2
- Add patch to fix build with -Werror=format-security
- Remove old, obsolete security patch

* Thu Oct 23 2008 Lev Givon <lev@mandriva.org> 0:3.0.2-2mdv2009.1
+ Revision: 296623
- Bump release to build against the newer cxsparse devel package.

* Sat Aug 23 2008 Funda Wang <fwang@mandriva.org> 0:3.0.2-1mdv2009.0
+ Revision: 275369
- use correct api
- New version 3.0.2

* Fri Aug 08 2008 Thierry Vignaud <tv@mandriva.org> 0:3.0.1-2mdv2009.0
+ Revision: 268333
- rebuild early 2009.0 package (before pixel changes)

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

  + Frederik Himpe <fhimpe@mandriva.org>
    - New upstream version
    - New license policy

* Thu Jan 10 2008 Lev Givon <lev@mandriva.org> 0:3.0.0-6mdv2008.1
+ Revision: 147669
- Add pcre-devel and curl-devel build deps.

* Mon Jan 07 2008 David Walluck <walluck@mandriva.org> 0:3.0.0-5mdv2008.1
+ Revision: 146174
- Obsoletes/Provides: octave3-devel

* Tue Jan 01 2008 Lev Givon <lev@mandriva.org> 0:3.0.0-4mdv2008.1
+ Revision: 140176
- Add glpk and sparse matrix package build dependencies.

* Tue Jan 01 2008 David Walluck <walluck@mandriva.org> 0:3.0.0-3mdv2008.1
+ Revision: 140016
- add desktop-file-utils deps
- fix rm in %%install
- add all fixes from octave3 and obsolete it
- enable make check

* Mon Dec 31 2007 David Walluck <walluck@mandriva.org> 3.0.0-2mdv2008.1
+ Revision: 139940
- add sources
- define octave_api for octave-forge
- use macros instead of shell vars
- bunzip2 sources and patches

* Sat Dec 29 2007 trem <trem@mandriva.org> 3.0.0-1mdv2008.1
+ Revision: 139030
- update to 3.0.0
- update to 3.0.0

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request
    - fix summary

* Thu Nov 29 2007 Lev Givon <lev@mandriva.org> 2.1.73-3mdv2008.1
+ Revision: 113953
- Update build requirements, build against lapack 3.1.1.
- import octave


* Sat Jul 22 2006 Giuseppe Ghibò <ghibo@mandriva.com> 2.1.73-2mdv2007.0
- Fixed libhdf5 dep on X86-64.
- Use gfortran.

* Tue Apr 18 2006 David Walluck <walluck@mandriva.org> 2.1.73-1mdk
- 2.1.73
- remove PreReq use

* Fri Mar 17 2006 Giuseppe Ghibò <ghibo@mandriva.coM> 2.1.72-1mdk
- 2.1.72.

* Thu Jul 28 2005 Gaetan Lehmann <glehmann@deborah.mandriva.com> 2.1.71-2mdk
- rebuild against new libblas
- BuildRequires liblas3-devel and liblapack-devel

* Wed Jul 20 2005 Nicolas Lécureuil <neoclust@mandriva.org> 2.1.71-1mdk
- New release

* Tue Feb 08 2005 Abel Cheung <deaddog@mandrake.org> 2.1.64-2mdk
- Rebuild against new readline
- multiarch

* Sun Dec 26 2004 Abel Cheung <deaddog@mandrake.org> 2.1.64-1mdk
- New release
- Some instruction on how to add atlas support
- Remove munge-texi, not for public consumption
- Drop external file which actually is inside source
- Split documentation package

* Wed Dec 08 2004 Abel Cheung <deaddog@mandrake.org> 2.1.63-3mdk
- Remove old artifact

* Tue Dec 07 2004 Abel Cheung <deaddog@mandrake.org> 2.1.63-2mdk
- Rebuild to get back binary RPM

* Thu Dec 02 2004 Abel Cheung <deaddog@mandrake.org> 2.1.63-1mdk 
- New version
- Fix BuildRequires and add others
- Fix P1 to use mktemp (the program 'tempfile' is no more)
- No GUI, shouldn't need menu

* Thu Sep 23 2004 Lenny Cartier <lenny@mandrakesoft.com> 2.1.59-1mdk
- 2.1.59

* Tue Jun 29 2004 Thierry Vignaud <tvignaud@mandrakesoft.com> 2.1.57-2mdk
- rebuild for new g++

* Tue Apr 06 2004 Thierry Vignaud <tvignaud@mandrakesoft.com> 2.1.57-1mdk
- new release

* Fri Feb 13 2004 David Walluck <walluck@linux-mandrake.com> 2.1.53-1mdk
- 2.1.53
- add epochs
- move `munge-texi' to %%{_bindir}

* Thu Dec 04 2003 Thierry Vignaud <tvignaud@mandrakesoft.com> 2.1.52-1mdk
- new release

* Mon Aug 11 2003 Buchan Milne <bgmilne@linux-mandrake.com> 2.1.50-2mdk
- rebuild

* Wed Jul 02 2003 Thierry Vignaud <tvignaud@mandrakesoft.com> 2.1.50-1mdk
- new release

* Wed Jun 25 2003 Thierry Vignaud <tvignaud@mandrakesoft.com> 2.1.49-1mdk
- new release

* Tue Apr 29 2003 Thierry Vignaud <tvignaud@mandrakesoft.com> 2.1.44-2mdk
- fix buildrequires

* Tue Feb 04 2003 Thierry Vignaud <tvignaud@mandrakesoft.com> 2.1.44-1mdk
- new release

* Fri Jan 03 2003 Thierry Vignaud <tvignaud@mandrakesoft.com> 2.1.42-1mdk
- new release
- add source url

* Thu Dec 12 2002 Olivier Thauvin <thauvin@aerov.jussieu.fr> 2.1.40-1mdk
- 2.1.40
- remove Patch 2,10,11

* Fri Aug 16 2002 Giuseppe Ghibò <ghibo@mandrakesoft.com> 2.1.36-4mdk
- png icons.
- BuildRequires: tetex-latex.
- use -fno-fast-math.

* Fri Aug 16 2002 Thierry Vignaud <tvignaud@mandrakesoft.com> 2.1.36-3mdk
- rebuild for g++-3.2 new ABI
- s/tar xfvy/%%setup -a2/
- patch 1 : use secure temp file in octave-bug
- patch 2 : update doc
- parallel build
- add emacs mode
- Buildrequires: texinfo, gcc-g77, libf2c0, readline-devel, libncurses-devel,
  gperf, gnuplot, fftw-devel >= 2.1.3, dejagnu
- Quel Qun <kelk1 at sbcglobal dot net> :
	o patch 10: use the right texi2html parameters (Quel Qun)
	o patch 11: transform file-ptr-stream.h from cvs
	o Buildrequires tetex-dvips
	o add doc/interpreter to %%doc

* Wed Jul 24 2002 Thierry Vignaud <tvignaud@mandrakesoft.com> 2.1.36-2mdk
- rebuild for new readline

* Tue May 21 2002 Thierry Vignaud <tvignaud@mandrakesoft.com> 2.1.36-1mdk
- new release

* Fri Apr 12 2002 Thierry Vignaud <tvignaud@mandrakesoft.com> 2.1.35-1mdk
- new release
- add otags(1)

* Wed Aug 22 2001 Lenny Cartier <lenny@mandrakesoft.com> 2.0.16-11mdk
- rebuild

* Mon May 28 2001  Daouda Lo <daouda@mandrakesoft.com> 2.0.16-10mdk
- Buildrequires : egcs-c++
- upload in contribs

* Mon May 28 2001  Daouda Lo <daouda@mandrakesoft.com> 2.0.16-9mdk
- add egcs in builrequires

* Sun May  6 2001 Guillaume Cottenceau <gc@mandrakesoft.com> 2.0.16-8mdk
- rebuild against latest libc++

* Tue Jan 23 2001 Lenny Cartier <lenny@mandrakesoft.com> 2.0.16-7mdk
- build with egcs

* Wed Sep 13 2000 Vincent Saugey <vince@mandrakesoft.com> 2.0.16-6mdk
- Rebuild with r-path (octave lib ont in /usr/lib/)

* Mon Aug 07 2000 Frederic Lepied <flepied@mandrakesoft.com> 2.0.16-5mdk
- automatically added BuildRequires

* Wed Jul 26 2000 Vincent Saugey <vince@mandrakesoft.com> 2.0.16-4mdk
- Macros, BM, add multiple icons sizes

* Wed Apr 12 2000 Vincent Saugey <vince@mandrakesoft.com> 2.0.16-3mdk
- strip oct file
- add menu entry
 
* Tue Mar 21 2000 Vincent Saugey <vince@mandrakesoft.com> 2.0.16-2mdk
- corrected for new groups

* Thu Mar 09 2000 Lenny Cartier <lenny@mandrakesoft.com>
- mandrake build
- v2.0.16

* Fri Oct 23 1998 Jeff Johnson <jbj@redhat.com>
- update to 2.0.13.90

* Thu Jul  9 1998 Jeff Johnson <jbj@redhat.com>
- repackage in powertools.

* Thu Jun 11 1998 Andrew Veliath <andrewtv@usa.net>
- Add %%attr, build as user.

* Mon Jun 1 1998 Andrew Veliath <andrewtv@usa.net>
- Add BuildRoot, installinfo, require gnuplot, description from
  Octave's web page, update to Octave 2.0.13.
- Adapt from existing spec file.

* Tue Dec  2 1997 Otto Hammersmith <otto@redhat.com>
- removed libreadline stuff from the file list

* Mon Nov 24 1997 Otto Hammersmith <otto@redhat.com>
- changed configure command to put things in $RPM_ARCH-rehat-linux, 
  rather than genereated one... was causing problems between building 
  on i686 build machine.

* Mon Nov 17 1997 Otto Hammersmith <otto@redhat.com>
- moved buildroot from /tmp to /var/tmp

* Mon Sep 22 1997 Mike Wangsmo <wanger@redhat.com>
- Upgraded to version 2.0.9 and built for glibc system

* Thu May 01 1997 Michael Fulbright <msf@redhat.com>
- Updated to version 2.0.5 and changed to build using a BuildRoot
